@@ -688,7 +688,7 @@ effect:
         # plot image
         self.plot_image(best, name=os.path.join(os.getcwd(),self.dir,'BestImage.pdf'), chi2=f'chi2={fdatabest:.1f}')
         # save image
-        self.imagetofits(best[0,:,:,0], ftot[id], fdatabest, frglbest, name=os.path.join(os.getcwd(),self.dir,'BestImage.fits'))
+        self.imagetofits(best, ftot[id], fdatabest, frglbest, name=os.path.join(os.getcwd(),self.dir,'BestImage.fits'))
 
 
     def imagetofits(self, image, ftot, fdata, frgl, name='Image.fits'):
@@ -1016,8 +1016,6 @@ effect:
             uabove = ubelow +1
             vabove = vbelow +1
             coords = tf.constant([[[0,ubelow[i],vbelow[i]] for i in range(len(ufunc))]])
-            print(coords)
-            print(coord[63,63])
             interpValues =  tf.gather_nd(grid,coords)*(uabove-ufunc)*(vabove-vfunc)
             coords1 =tf.constant([[[0,uabove[i],vabove[i]] for i in range(len(ufunc))]])
             interpValues += tf.gather_nd(grid,coords1)*(ufunc-ubelow)*(vfunc-vbelow)
